Data documentation compiled by Great Expectations

Documentation autogenerated using Great Expectations.
This is a beta feature! Expect changes in API, behavior, and design.

### Overview

#### Dataset info

Number of variables | 7
Number of observations | 1313
Missing cells | 6.06%

#### Variable types

int | 3
float | 1
string | 3
-- | 0

#### Expectation types

- expect_column_proportion_of_unique_values_to_be_between 7
- expect_column_unique_value_count_to_be_between 7
- expect_column_values_to_be_in_set 7
- expect_column_values_to_be_in_type_list 7
- expect_column_values_to_not_be_null 7
- expect_column_distinct_values_to_be_in_set 4
- expect_column_values_to_not_match_regex 3
- expect_column_values_to_be_unique 1
- expect_table_row_count_to_be_between 1
- expect_column_quantile_values_to_be_between 1
- expect_column_kl_divergence_to_be_less_than 1
- expect_column_median_to_be_between 1
- expect_table_columns_to_match_ordered_list 1
- expect_column_max_to_be_between 1
- expect_column_mean_to_be_between 1
- expect_column_min_to_be_between 1

### Unnamed: 0 (type: int)

#### Properties

Distinct (n) | 1313
Distinct (%) | 100.0%
Missing (n) | 0
Missing (%) | 0.0%

#### Example values

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20

#### Expectation types

- expect_column_values_to_be_in_type_list True
- expect_column_unique_value_count_to_be_between True
- expect_column_proportion_of_unique_values_to_be_between True
- expect_column_values_to_not_be_null True
- expect_column_values_to_be_in_set False
- expect_column_values_to_be_unique True

### Name (type: string)

#### Properties

Distinct (n) | 1310
Distinct (%) | 99.8%
Missing (n) | 0
Missing (%) | 0.0%

#### Example values

Carlsson, Mr Frans Olof Connolly, Miss Kate Kelly, Mr James Carter, Rev Ernest Courtenay Compton, Miss Sara Rebecca Drew, Mr James Vivian Duran y More, Miss Asuncion Eustis, Miss Elizabeth Mussey Hee, Mr Ling Hegarty, Miss Nora Herman, Miss Alice Kenyon, Mr Frederick R Louch, Mrs Charles Alexander (Alice Adelaide) Markim, Mr Johann Murphy, Miss Katherine Myles, Mr Thomas Francis Panula, Mrs John Peacock, Miss Treasteall Tannous, Mr Thomas Veale, Mr James

#### Expectation types

- expect_column_values_to_be_in_type_list True
- expect_column_unique_value_count_to_be_between True
- expect_column_proportion_of_unique_values_to_be_between True
- expect_column_values_to_not_be_null True
- expect_column_values_to_be_in_set False
- expect_column_values_to_not_match_regex False

### PClass (type: string)

#### Properties

Distinct (n) | 4
Distinct (%) | 0.3%
Missing (n) | 0
Missing (%) | 0.0%

#### Example values

3rd 1st 2nd *

#### Value Counts

#### Expectation types

- expect_column_values_to_be_in_type_list True
- expect_column_unique_value_count_to_be_between True
- expect_column_proportion_of_unique_values_to_be_between True
- expect_column_values_to_not_be_null True
- expect_column_values_to_be_in_set False
- expect_column_values_to_not_match_regex True
- expect_column_distinct_values_to_be_in_set True

### Age (type: float)

#### Properties

Distinct (n) | 75
Distinct (%) | 9.9%
Missing (n) | 557
Missing (%) | 42.4%

#### Quantiles

0.05 | 6.0
Q1 | 21.0
Median | 28.0
Q3 | 39.0
0.95 | 57.0

#### Statistics

Mean | 30.40
Minimum | 0.17
Maximum | 71.00

#### Histogram

#### Example values

22.0 21.0 30.0 18.0 36.0 24.0 26.0 27.0 28.0 19.0 20.0 23.0 25.0 32.0 45.0 29.0 31.0 33.0 35.0 39.0

#### Expectation types

- expect_column_values_to_be_in_type_list True
- expect_column_unique_value_count_to_be_between True
- expect_column_proportion_of_unique_values_to_be_between True
- expect_column_values_to_not_be_null True
- expect_column_values_to_be_in_set False
- expect_column_min_to_be_between True
- expect_column_max_to_be_between True
- expect_column_mean_to_be_between True
- expect_column_median_to_be_between True
- expect_column_quantile_values_to_be_between True
- expect_column_kl_divergence_to_be_less_than True

### Sex (type: string)

#### Properties

Distinct (n) | 2
Distinct (%) | 0.2%
Missing (n) | 0
Missing (%) | 0.0%

#### Example values

male female

#### Value Counts

#### Expectation types

- expect_column_values_to_be_in_type_list True
- expect_column_unique_value_count_to_be_between True
- expect_column_proportion_of_unique_values_to_be_between True
- expect_column_values_to_not_be_null True
- expect_column_values_to_be_in_set False
- expect_column_values_to_not_match_regex True
- expect_column_distinct_values_to_be_in_set True

### Survived (type: int)

#### Properties

Distinct (n) | 2
Distinct (%) | 0.2%
Missing (n) | 0
Missing (%) | 0.0%

#### Example values

0 1

#### Value Counts

#### Expectation types

- expect_column_values_to_be_in_type_list True
- expect_column_unique_value_count_to_be_between True
- expect_column_proportion_of_unique_values_to_be_between True
- expect_column_values_to_not_be_null True
- expect_column_values_to_be_in_set False
- expect_column_distinct_values_to_be_in_set True

### SexCode (type: int)

#### Properties

Distinct (n) | 2
Distinct (%) | 0.2%
Missing (n) | 0
Missing (%) | 0.0%

#### Example values

0 1

#### Value Counts

#### Expectation types

- expect_column_values_to_be_in_type_list True
- expect_column_unique_value_count_to_be_between True
- expect_column_proportion_of_unique_values_to_be_between True
- expect_column_values_to_not_be_null True
- expect_column_values_to_be_in_set False
- expect_column_distinct_values_to_be_in_set True